@@ -33,6 +33,7 @@
 #define DEBUG_INFO __FILE__, __LINE__, __FUNCTION__
 #define MIME_TYPE_DIRECTORY "folder"
 #define MIME_TYPE_ARCHIVE "application/x-archive"
+#define DEF_ACTION_CALLBACK(x) void x (GSimpleAction *action, GVariant *parameter, gpointer user_data);
 
 #define get_home_relative_path(x)        \
 	g_strconcat (g_get_home_dir (), \
@@ -140,6 +141,7 @@ char *              _g_path_get_dir_name           (const char          *path);
 char *              _g_path_remove_level           (const char          *path);
 char *              _g_path_remove_ending_separator(const char          *path);
 char *              _g_path_remove_extension       (const char          *path);
+char *		    _g_path_remove_first_extension (const gchar		*path);
 gboolean            _g_path_is_parent_of           (const char          *dirname,
 						    const char          *filename);
 const char *        _g_path_get_relative_basename  (const char          *path,
